@@ -3,8 +3,8 @@ class BaseError(Exception):
 		Base Error
 	"""
 	def __init__(self, message=None):
-		self.message = message or self.__doc__.strip()
-		super(BaseError, self).__init__(self.message)
+		self.message = message or self.__doc__
+		super(BaseError, self).__init__(self.message.strip())
 
 
 class NonExistentDBError(BaseError):
