@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 from datetime import date
 
-class BaseType(object):
+class BaseType:
 
 	VALUES = ['individual','hogar']
 
@@ -13,7 +12,7 @@ class BaseType(object):
 			raise ValueError("Por favor ingresa un tipo de base valido: " + ", ".join(self.VALUES))
 		self.value = value
 
-class Frequency(object):
+class Frequency:
 
 	VALUES = {
         'trimestre': 4,
@@ -28,7 +27,7 @@ class Frequency(object):
 			raise ValueError("Por favor ingresa un tipo de base valido: " + ", ".join(self.VALUES.keys()))
 		self.value = value
 
-class Period(object):
+class Period:
 
 	VALUES = [1,2,3,4]
 
@@ -43,13 +42,13 @@ class Period(object):
 			raise ValueError("Por favor ingresa un numero de trimeste valido: " + ",".join(map(str, self.VALUES)))
 		self.value = value
 
-class Year(object):
+class Year:
 	def __get__(self, obj, *args):
 		return self.value
 
 	def __set__(self, obj, value):
 		current_year = date.today().year
 		if not (isinstance(value,int) and value <= current_year):
-			raise ValueError("El año debe ser menor o igual a {}.".format(current_year))
+			raise ValueError("El año debe ser un número menor o igual a {}.".format(current_year))
 		self.value = value
 
